@@ -4,44 +4,47 @@ import bz2
 import hashlib
 import imghdr
 import os
-import time
 import zlib
+import warnings
 
 from collections import namedtuple
 from enum import Enum
 from enum import IntEnum
-from pyasn1.type.univ import ObjectIdentifier
+from enum import IntFlag
 
-import six
+from pyasn1.type.univ import ObjectIdentifier
 
 from cryptography.hazmat.backends import openssl
 from cryptography.hazmat.primitives.asymmetric import ec
 from cryptography.hazmat.primitives.ciphers import algorithms
 
-from .decorators import classproperty
 from .types import FlagEnum
+from .decorators import classproperty
 from ._curves import BrainpoolP256R1, BrainpoolP384R1, BrainpoolP512R1, X25519, Ed25519
 
-__all__ = ['Backend',
-           'EllipticCurveOID',
-           'ECPointFormat',
-           'PacketTag',
-           'SymmetricKeyAlgorithm',
-           'PubKeyAlgorithm',
-           'CompressionAlgorithm',
-           'HashAlgorithm',
-           'RevocationReason',
-           'ImageEncoding',
-           'SignatureType',
-           'KeyServerPreferences',
-           'S2KGNUExtension',
-           'String2KeyType',
-           'TrustLevel',
-           'KeyFlags',
-           'Features',
-           'RevocationKeyClass',
-           'NotationDataFlags',
-           'TrustFlags']
+__all__ = [
+    'Backend',
+    'EllipticCurveOID',
+    'ECPointFormat',
+    'PacketTag',
+    'SymmetricKeyAlgorithm',
+    'PubKeyAlgorithm',
+    'CompressionAlgorithm',
+    'HashAlgorithm',
+    'RevocationReason',
+    'ImageEncoding',
+    'SignatureType',
+    'KeyServerPreferences',
+    'S2KGNUExtension',
+    'SecurityIssues',
+    'String2KeyType',
+    'TrustLevel',
+    'KeyFlags',
+    'Features',
+    'RevocationKeyClass',
+    'NotationDataFlags',
+    'TrustFlags',
+]
 
 
 # this is 50 KiB
@@ -283,6 +286,26 @@ class PubKeyAlgorithm(IntEnum):
                         PubKeyAlgorithm.RSASign,
                         PubKeyAlgorithm.FormerlyElGamalEncryptOrSign}
 
+    def validate_params(self, size):
+        min_size = MINIMUM_ASYMMETRIC_KEY_LENGTHS.get(self)
+        if min_size is not None:
+            if isinstance(min_size, set):
+                # ECC
+                curve = size
+                safe_curves = min_size
+                if curve in safe_curves:
+                    return SecurityIssues.OK
+                else:
+                    return SecurityIssues.InsecureCurve
+            else:
+                # not ECC
+                if size >= min_size:
+                    return SecurityIssues.OK
+                else:
+                    return SecurityIssues.AsymmetricKeyLengthIsTooShort
+        # min_size is None
+        return SecurityIssues.BrokenAsymmetricFunc
+
 
 class CompressionAlgorithm(IntEnum):
     """Supported compression algorithms."""
@@ -311,9 +334,6 @@ class CompressionAlgorithm(IntEnum):
         raise NotImplementedError(self)
 
     def decompress(self, data):
-        if six.PY2:
-            data = bytes(data)
-
         if self is CompressionAlgorithm.Uncompressed:
             return data
 
@@ -343,6 +363,9 @@ class HashAlgorithm(IntEnum):
     SHA384 = 0x09
     SHA512 = 0x0A
     SHA224 = 0x0B
+    #SHA3_256 = 13
+    #SHA3_384 = 14
+    #SHA3_512 = 15
 
     def __init__(self, *args):
         super(self.__class__, self).__init__()
@@ -364,6 +387,27 @@ class HashAlgorithm(IntEnum):
     def is_supported(self):
         return True
 
+    @property
+    def is_second_preimage_resistant(self):
+        return self in {HashAlgorithm.SHA1}
+
+    @property
+    def is_collision_resistant(self):
+        return self in {HashAlgorithm.SHA256, HashAlgorithm.SHA384, HashAlgorithm.SHA512}
+
+    @property
+    def is_considered_secure(self):
+        if self.is_collision_resistant:
+            return SecurityIssues.OK
+
+        warnings.warn('Hash function {hash} is not considered collision resistant'.format(hash=repr(self)))
+        issues = SecurityIssues.HashFunctionNotCollisionResistant
+
+        if not self.is_second_preimage_resistant:
+            issues |= SecurityIssues.HashFunctionNotSecondPreimageResistant
+
+        return issues
+
 
 class RevocationReason(IntEnum):
     """Reasons explaining why a key or certificate was revoked."""
@@ -540,3 +584,46 @@ class TrustFlags(FlagEnum):
     SubRevoked = 0x40
     Disabled = 0x80
     PendingCheck = 0x100
+
+
+class SecurityIssues(IntFlag):
+    OK = 0
+    WrongSig = (1 << 0)
+    Expired = (1 << 1)
+    Disabled = (1 << 2)
+    Revoked = (1 << 3)
+    Invalid = (1 << 4)
+    BrokenAsymmetricFunc = (1 << 5)
+    HashFunctionNotCollisionResistant = (1 << 6)
+    HashFunctionNotSecondPreimageResistant = (1 << 7)
+    AsymmetricKeyLengthIsTooShort = (1 << 8)
+    InsecureCurve = (1 << 9)
+    NoSelfSignature = (1 << 10)
+
+    @property
+    def causes_signature_verify_to_fail(self):
+        return self in {
+            SecurityIssues.WrongSig,
+            SecurityIssues.Expired,
+            SecurityIssues.Disabled,
+            SecurityIssues.Invalid,
+            SecurityIssues.NoSelfSignature,
+        }
+
+
+# https://safecurves.cr.yp.to/
+SAFE_CURVES = {
+    EllipticCurveOID.Curve25519,
+    EllipticCurveOID.Ed25519,
+}
+
+MINIMUM_ASYMMETRIC_KEY_LENGTHS = {
+    PubKeyAlgorithm.RSAEncryptOrSign: 2048,
+    PubKeyAlgorithm.RSASign: 2048,
+    PubKeyAlgorithm.ElGamal: 2048,
+    PubKeyAlgorithm.DSA: 2048,
+    ##
+    PubKeyAlgorithm.ECDSA: SAFE_CURVES,
+    PubKeyAlgorithm.EdDSA: SAFE_CURVES,
+    PubKeyAlgorithm.ECDH: SAFE_CURVES,
+}
