@@ -2,7 +2,6 @@
 """
 import contextlib
 import functools
-import six
 import logging
 
 try:
@@ -93,7 +92,11 @@ class KeyAction(object):
                     break
 
             else:  # pragma: no cover
-                raise PGPError("Key {keyid:s} does not have the required usage flag {flags:s}".format(**em))
+                warning = "Key {keyid:s} does not have the required usage flag {flags:s}".format(**em)
+                if key._require_usage_flags:
+                    raise PGPError(warning)
+                else:
+                    logging.warning(warning)
 
         else:
             _key = key
@@ -101,7 +104,7 @@ class KeyAction(object):
         if _key is not key:
             em['subkeyid'] = _key.fingerprint.keyid
             logging.debug("Key {keyid:s} does not have the required usage flag {flags:s}; using subkey {subkeyid:s}"
-                          "".format(**em), stacklevel=4)
+                          "".format(**em))  # TODO: consider adding stacklevel=4 when we only support Python >= 3.8
 
         yield _key
 
@@ -112,8 +115,7 @@ class KeyAction(object):
                                "".format(attr=attr, eval=str(expected), got=str(getattr(key, attr))))
 
     def __call__(self, action):
-        # @functools.wraps(action)
-        @six.wraps(action)
+        @functools.wraps(action)
         def _action(key, *args, **kwargs):
             if key._key is None:
                 raise PGPError("No key!")
