@@ -4,21 +4,20 @@ import pytest
 import glob
 try:
     import gpg
-except (ModuleNotFoundError, NameError):
+except ImportError:
     gpg = None
+    gpg_ver = 'unknown'
+else:
+    # get the GnuPG version
+    gpg_ver = list(filter(lambda x: x.protocol == gpg.constants.PROTOCOL_OpenPGP, gpg.core.get_engine_info()))[0].version
+
 import os
 import sys
 
-from distutils.version import LooseVersion
-
 from cryptography.hazmat.backends import openssl
 
-openssl_ver = LooseVersion(openssl.backend.openssl_version_text().split(' ')[1])
-gpg_ver = LooseVersion('0')
+openssl_ver = openssl.backend.openssl_version_text().split(' ')[1]
 gnupghome = os.path.join(os.path.dirname(__file__), 'gnupghome')
-if gpg:
-    gpgme_ver = gpg.core.check_version()
-
 
 # ensure external commands we need to run exist
 
@@ -51,9 +50,6 @@ def pytest_configure(config):
         for fpath in iter(f for cg in clear_globs for f in glob.glob(cg)):
             os.unlink(fpath)
 
-        # get the GnuPG version
-        gpg_ver.parse(gpg.core.get_engine_info()[0].version)
-
         # check that there are no keys loaded, now
         with gpg.Context(offline=True) as c:
             c.set_engine_info(gpg.constants.PROTOCOL_OpenPGP, home_dir=gnupghome)
@@ -64,8 +60,8 @@ def pytest_configure(config):
     else:
         # we're not running integration tests
         print("running without integration tests")
-        # if we're on Travis, this is an error
-        if os.getenv('TRAVIS_PYTHON_VERSION'):
+        # if we're on GitHub CI, this is an error
+        if os.getenv('CI'):
             sys.exit(1)
 
     # display the working directory and the OpenSSL/GPG/pgpdump versions
