@@ -4,7 +4,7 @@ import pytest
 
 import glob
 import os
-from datetime import datetime
+from datetime import datetime, timezone
 
 from pgpy.constants import HashAlgorithm
 from pgpy.constants import PubKeyAlgorithm
@@ -14,6 +14,7 @@ from pgpy.pgp import PGPMessage
 from pgpy.pgp import PGPSignature
 from pgpy.types import Armorable
 
+
 blocks = sorted(glob.glob('tests/testdata/blocks/*.asc'))
 block_attrs = {
     'tests/testdata/blocks/message.ascii.asc':
@@ -130,9 +131,9 @@ block_attrs = {
          ('type',          'encrypted')],
 
     'tests/testdata/blocks/revochiio.asc':
-        [('created',       datetime(2014, 9, 11, 22, 55, 53)),
+        [('created',       datetime(2014, 9, 11, 22, 55, 53, tzinfo=timezone.utc)),
          ('fingerprint',   "AE15 9FF3 4C1A 2426 B7F8 0F1A 560C F308 EF60 CFA3"),
-         ('expires_at',    datetime(2018, 9, 12, 1, 0, 59)),
+         ('expires_at',    datetime(2018, 9, 12, 1, 0, 59, tzinfo=timezone.utc)),
          ('is_expired',    True),
          ('is_primary',    True),
          ('is_protected',  False),
@@ -144,13 +145,13 @@ block_attrs = {
          ('signers',       {'560CF308EF60CFA3'}),],
 
     'tests/testdata/blocks/expyro.asc':
-        [('created',       datetime(1970, 1, 1)),
-         ('expires_at',    datetime(1970, 1, 2)),
+        [('created',       datetime(1970, 1, 1, tzinfo=timezone.utc)),
+         ('expires_at',    datetime(1970, 1, 2, tzinfo=timezone.utc)),
          ('fingerprint',   '24EB C1B0 29B1 FCF8 29A5  C150 1A48 291A FB91 A533'),
          ('is_expired',    True),],
 
     'tests/testdata/blocks/rsapubkey.asc':
-        [('created',       datetime(2014, 7, 23, 21, 19, 24)),
+        [('created',       datetime(2014, 7, 23, 21, 19, 24, tzinfo=timezone.utc)),
          ('expires_at',    None),
          ('fingerprint',   "F429 4BC8 094A 7E05 85C8 5E86 3747 3B37 58C4 4F36"),
          ('is_expired',    False),
@@ -164,7 +165,7 @@ block_attrs = {
          ('signers',       set()),],
 
     'tests/testdata/blocks/rsaseckey.asc':
-        [('created',       datetime(2014, 7, 23, 21, 19, 24)),
+        [('created',       datetime(2014, 7, 23, 21, 19, 24, tzinfo=timezone.utc)),
          ('expires_at',    None),
          ('fingerprint',   "F429 4BC8 094A 7E05 85C8 5E86 3747 3B37 58C4 4F36"),
          ('is_expired',    False),
@@ -187,7 +188,7 @@ block_attrs = {
                    b'\x55\x5d'),
          ('cipherprefs',    []),
          ('compprefs',      []),
-         ('created',        datetime.utcfromtimestamp(1402615373)),
+         ('created',        datetime.fromtimestamp(1402615373, timezone.utc)),
          ('embedded',       False),
          ('exportable',     True),
          ('features',       set()),
@@ -208,7 +209,7 @@ block_attrs = {
          ('type',           SignatureType.BinaryDocument)],
 
     'tests/testdata/blocks/eccpubkey.asc':
-        [('created',       datetime(2010, 9, 17, 20, 33, 49)),
+        [('created',       datetime(2010, 9, 17, 20, 33, 49, tzinfo=timezone.utc)),
          ('expires_at',    None),
          ('fingerprint',   "502D 1A53 65D1 C0CA A699 4539 0BA5 2DF0 BAA5 9D9C"),
          ('is_expired',    False),
@@ -222,7 +223,7 @@ block_attrs = {
          ('signers',       set()),],
 
     'tests/testdata/blocks/eccseckey.asc':
-        [('created',       datetime(2010, 9, 17, 20, 33, 49)),
+        [('created',       datetime(2010, 9, 17, 20, 33, 49, tzinfo=timezone.utc)),
          ('expires_at',    None),
          ('fingerprint',   "502D 1A53 65D1 C0CA A699 4539 0BA5 2DF0 BAA5 9D9C"),
          ('is_expired',    False),
@@ -236,7 +237,7 @@ block_attrs = {
          ('signers',       set()),],
 
     'tests/testdata/blocks/dsaseckey.asc':
-        [('created',       datetime(2017, 2, 21, 19, 21, 41)),
+        [('created',       datetime(2017, 2, 21, 19, 21, 41, tzinfo=timezone.utc)),
          ('expires_at',    None),
          ('fingerprint',   "2B5B BB14 3BA0 B290 DCEE 6668 B798 AE89 9087 7201"),
          ('is_expired',    False),
@@ -247,7 +248,7 @@ block_attrs = {
          ('key_algorithm', PubKeyAlgorithm.DSA),],
 
     'tests/testdata/blocks/dsapubkey.asc':
-        [('created',       datetime(2017, 2, 21, 19, 21, 41)),
+        [('created',       datetime(2017, 2, 21, 19, 21, 41, tzinfo=timezone.utc)),
          ('expires_at',    None),
          ('fingerprint',   "2B5B BB14 3BA0 B290 DCEE 6668 B798 AE89 9087 7201"),
          ('is_expired',    False),
@@ -258,7 +259,7 @@ block_attrs = {
          ('key_algorithm', PubKeyAlgorithm.DSA),],
 
     'tests/testdata/blocks/openpgp.js.pubkey.asc':
-        [('created',        datetime(2016, 6, 2, 21, 57, 13)),
+        [('created',        datetime(2016, 6, 2, 21, 57, 13, tzinfo=timezone.utc)),
          ('expires_at',     None),
          ('fingerprint',    "C7C3 8ECE E94A 4AD3 2DDB  064E 14AB 44C7 4D1B DAB8"),
          ('is_expired',     False),
@@ -272,7 +273,7 @@ block_attrs = {
          ('signers',        set()), ],
 
     'tests/testdata/blocks/openpgp.js.seckey.asc':
-        [('created',        datetime(2016, 6, 2, 21, 57, 13)),
+        [('created',        datetime(2016, 6, 2, 21, 57, 13, tzinfo=timezone.utc)),
          ('expires_at',     None),
          ('fingerprint',    "C7C3 8ECE E94A 4AD3 2DDB  064E 14AB 44C7 4D1B DAB8"),
          ('is_expired',     False),
@@ -286,11 +287,11 @@ block_attrs = {
          ('signers',        set()), ],
 
     'tests/testdata/blocks/signature.expired.asc':
-        [('created',       datetime(2014, 9, 28, 20, 54, 42)),
+        [('created',       datetime(2014, 9, 28, 20, 54, 42, tzinfo=timezone.utc)),
          ('is_expired',    True),],
 
     'tests/testdata/blocks/signature.non-exportable.asc':
-        [('created',       datetime(2017, 2, 21, 20, 43, 34)),
+        [('created',       datetime(2017, 2, 21, 20, 43, 34, tzinfo=timezone.utc)),
          ('exportable',    False),]
 }
 
