@@ -8,13 +8,13 @@ import copy
 import glob
 try:
     import gpg
-except (ModuleNotFoundError, NameError):
+except ImportError:
     gpg = None
 import itertools
 import os
 import time
 import warnings
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 
 from pgpy import PGPKey
 from pgpy import PGPMessage
@@ -31,6 +31,7 @@ from pgpy.constants import PubKeyAlgorithm
 from pgpy.constants import RevocationReason
 from pgpy.constants import SignatureType
 from pgpy.constants import SymmetricKeyAlgorithm
+from pgpy.errors import PGPError
 from pgpy.packet import Packet
 from pgpy.packet.packets import PrivKeyV4
 from pgpy.packet.packets import PrivSubKeyV4
@@ -42,20 +43,24 @@ enc_msgs = [ PGPMessage.from_file(f) for f in sorted(glob.glob('tests/testdata/m
 class TestPGPMessage(object):
     @staticmethod
     def gpg_message(msg):
+        ret = None
         with gpg.Context(offline=True) as c:
             c.set_engine_info(gpg.constants.PROTOCOL_OpenPGP, home_dir=gnupghome)
             msg, _ = c.verify(gpg.Data(string=str(msg)))
-        return msg
+            ret = bytes(msg)
+        return ret
 
     @staticmethod
     def gpg_decrypt(msg, passphrase):
         try:
+            ret = None
             with gpg.Context(armor=True, offline=True, pinentry_mode=gpg.constants.PINENTRY_MODE_LOOPBACK) as c:
                 c.set_engine_info(gpg.constants.PROTOCOL_OpenPGP, file_name='/usr/bin/gpg', home_dir=gnupghome)
                 mtxt, decres, _ = c.decrypt(gpg.Data(string=str(msg)), passphrase=passphrase.encode('utf-8'), verify=False)
 
-            assert decres
-            return mtxt
+                assert decres
+                ret = bytes(mtxt)
+            return ret
 
         except gpg.errors.GPGMEError:
             # if we got here, it's because gpgme/gpg-agent are not respecting the call to gpgme_set_passphrase_cb
@@ -217,15 +222,15 @@ def userphoto():
 
 
 # TODO: add more keyspecs
-pkeyspecs = ((PubKeyAlgorithm.RSAEncryptOrSign, 1024),
-             (PubKeyAlgorithm.DSA, 1024),
+pkeyspecs = ((PubKeyAlgorithm.RSAEncryptOrSign, 2048),
+             (PubKeyAlgorithm.DSA, 2048),
              (PubKeyAlgorithm.ECDSA, EllipticCurveOID.NIST_P256),
              (PubKeyAlgorithm.EdDSA, EllipticCurveOID.Ed25519),)
 
 
-skeyspecs = ((PubKeyAlgorithm.RSAEncryptOrSign, 1024),
-             (PubKeyAlgorithm.DSA, 1024),
-             (PubKeyAlgorithm.ElGamal, 1024),
+skeyspecs = ((PubKeyAlgorithm.RSAEncryptOrSign, 2048),
+             (PubKeyAlgorithm.DSA, 2048),
+             (PubKeyAlgorithm.ElGamal, 2048),
              (PubKeyAlgorithm.ECDSA, EllipticCurveOID.SECP256K1),
              (PubKeyAlgorithm.ECDH, EllipticCurveOID.Brainpool_P256),
              (PubKeyAlgorithm.EdDSA, EllipticCurveOID.Ed25519),
@@ -245,9 +250,9 @@ class TestPGPKey_Management(object):
             c.set_engine_info(gpg.constants.PROTOCOL_OpenPGP, home_dir=gnupghome)
             data, vres = c.verify(gpg.Data(string=str(key)))
 
-        assert vres
+            assert vres
 
-    @pytest.mark.run('first')
+    @pytest.mark.order(1)
     @pytest.mark.parametrize('alg,size', pkeyspecs)
     def test_gen_key(self, alg, size):
         # create a primary key with a UID
@@ -271,7 +276,7 @@ class TestPGPKey_Management(object):
             # try to verify with GPG
             self.gpg_verify_key(key)
 
-    @pytest.mark.run(after='test_gen_key')
+    @pytest.mark.order(after='test_gen_key')
     @pytest.mark.parametrize('pkspec,skspec',
                              itertools.product(pkeyspecs, skeyspecs),
                              ids=['{}-{}-{}'.format(pk[0].name, sk[0].name, sk[1]) for pk, sk in itertools.product(pkeyspecs, skeyspecs)])
@@ -311,7 +316,7 @@ class TestPGPKey_Management(object):
             # try to verify with GPG
             self.gpg_verify_key(key)
 
-    @pytest.mark.run(after='test_add_subkey')
+    @pytest.mark.order(after='test_add_subkey')
     @pytest.mark.parametrize('pkspec', pkeyspecs, ids=[str(a) for a, s in pkeyspecs])
     def test_add_altuid(self, pkspec):
         if pkspec not in self.keys:
@@ -320,7 +325,7 @@ class TestPGPKey_Management(object):
         key = self.keys[pkspec]
         uid = PGPUID.new('T. Keyerson', 'Secondary UID', 'testkey@localhost.local')
 
-        expiration = datetime.utcnow() + timedelta(days=2)
+        expiration = datetime.now(timezone.utc) + timedelta(days=2)
 
         # add all of the sbpackets that only work on self-certifications
         with warnings.catch_warnings():
@@ -331,7 +336,7 @@ class TestPGPKey_Management(object):
                         hashes=[HashAlgorithm.SHA384],
                         compression=[CompressionAlgorithm.ZLIB],
                         key_expiration=expiration,
-                        keyserver_flags=0x80,
+                        keyserver_flags={KeyServerPreferences.NoModify},
                         keyserver='about:none',
                         primary=False)
 
@@ -344,7 +349,7 @@ class TestPGPKey_Management(object):
         assert sig.features == {Features.ModificationDetection}
         assert sig.key_expiration == expiration - key.created
         assert sig.keyserver == 'about:none'
-        assert sig.keyserverprefs == [KeyServerPreferences.NoModify]
+        assert sig.keyserverprefs == {KeyServerPreferences.NoModify}
 
         assert uid.is_primary is False
 
@@ -352,7 +357,7 @@ class TestPGPKey_Management(object):
             # try to verify with GPG
             self.gpg_verify_key(key)
 
-    @pytest.mark.run(after='test_add_altuid')
+    @pytest.mark.order(after='test_add_altuid')
     @pytest.mark.parametrize('pkspec', pkeyspecs, ids=[str(a) for a, s in pkeyspecs])
     def test_add_photo(self, pkspec, userphoto):
         if pkspec not in self.keys:
@@ -369,7 +374,7 @@ class TestPGPKey_Management(object):
             # try to verify with GPG
             self.gpg_verify_key(key)
 
-    @pytest.mark.run(after='test_add_photo')
+    @pytest.mark.order(after='test_add_photo')
     @pytest.mark.parametrize('pkspec', pkeyspecs, ids=[str(a) for a, s in pkeyspecs])
     def test_revoke_altuid(self, pkspec):
         if pkspec not in self.keys:
@@ -382,7 +387,7 @@ class TestPGPKey_Management(object):
         revsig = key.revoke(altuid)
         altuid |= revsig
 
-    @pytest.mark.run(after='test_remove_altuid')
+    @pytest.mark.order(after='test_revoke_altuid')
     @pytest.mark.parametrize('pkspec', pkeyspecs, ids=[str(a) for a, s in pkeyspecs])
     def test_remove_altuid(self, pkspec):
         if pkspec not in self.keys:
@@ -394,7 +399,7 @@ class TestPGPKey_Management(object):
 
         assert not key.get_uid('T. Keyerson')
 
-    @pytest.mark.run(after='test_remove_altuid')
+    @pytest.mark.order(after='test_remove_altuid')
     @pytest.mark.parametrize('pkspec', pkeyspecs, ids=[str(a) for a, s in pkeyspecs])
     def test_add_revocation_key(self, pkspec):
         if pkspec not in self.keys:
@@ -412,7 +417,7 @@ class TestPGPKey_Management(object):
             # try to verify with GPG
             self.gpg_verify_key(key)
 
-    @pytest.mark.run(after='test_add_revocation_key')
+    @pytest.mark.order(after='test_add_revocation_key')
     @pytest.mark.parametrize('pkspec', pkeyspecs, ids=[str(a) for a, s in pkeyspecs])
     def test_protect(self, pkspec):
         if pkspec not in self.keys:
@@ -432,7 +437,7 @@ class TestPGPKey_Management(object):
             # try to verify with GPG
             self.gpg_verify_key(key)
 
-    @pytest.mark.run(after='test_protect')
+    @pytest.mark.order(after='test_protect')
     @pytest.mark.parametrize('pkspec', pkeyspecs, ids=[str(a) for a, s in pkeyspecs])
     def test_unlock(self, pkspec):
         if pkspec not in self.keys:
@@ -447,7 +452,7 @@ class TestPGPKey_Management(object):
         with key.unlock('There Are Many Like It, But This Key Is Mine') as _unlocked:
             assert _unlocked.is_unlocked
 
-    @pytest.mark.run(after='test_unlock')
+    @pytest.mark.order(after='test_unlock')
     @pytest.mark.parametrize('pkspec', pkeyspecs, ids=[str(a) for a, s in pkeyspecs])
     def test_change_passphrase(self, pkspec):
         if pkspec not in self.keys:
@@ -459,7 +464,7 @@ class TestPGPKey_Management(object):
         with key.unlock('There Are Many Like It, But This Key Is Mine') as ukey:
             ukey.protect('This Password Has Been Changed', ukey._key.keymaterial.s2k.encalg, ukey._key.keymaterial.s2k.halg)
 
-    @pytest.mark.run(after='test_change_passphrase')
+    @pytest.mark.order(after='test_change_passphrase')
     @pytest.mark.parametrize('pkspec', pkeyspecs, ids=[str(a) for a, s in pkeyspecs])
     def test_unlock2(self, pkspec):
         if pkspec not in self.keys:
@@ -471,9 +476,9 @@ class TestPGPKey_Management(object):
         with key.unlock('This Password Has Been Changed') as ukey:
             assert ukey.is_unlocked
 
-    @pytest.mark.run(after='test_unlock2')
+    @pytest.mark.order(after='test_unlock2')
     @pytest.mark.parametrize('pkspec', pkeyspecs, ids=[str(a) for a, s in pkeyspecs])
-    def test_pub_from_sec(self, pkspec):
+    def test_pub_from_spec(self, pkspec):
         if pkspec not in self.keys:
             pytest.skip('Keyspec {} not in keys; must not have generated'.format(pkspec))
 
@@ -493,7 +498,7 @@ class TestPGPKey_Management(object):
             # try to verify with GPG
             self.gpg_verify_key(pub)
 
-    @pytest.mark.run(after='test_pub_from_spec')
+    @pytest.mark.order(after='test_pub_from_spec')
     @pytest.mark.parametrize('pkspec,skspec',
                              itertools.product(pkeyspecs, skeyspecs),
                              ids=['{}-{}-{}'.format(pk[0].name, sk[0].name, sk[1]) for pk, sk in
@@ -530,7 +535,7 @@ class TestPGPKey_Management(object):
             # try to verify with GPG
             self.gpg_verify_key(key)
 
-    @pytest.mark.run(after='test_revoke_subkey')
+    @pytest.mark.order(after='test_revoke_subkey')
     @pytest.mark.parametrize('pkspec', pkeyspecs, ids=[str(a) for a, s in pkeyspecs])
     def test_revoke_key(self, pkspec):
         if pkspec not in self.keys:
@@ -554,7 +559,7 @@ class TestPGPKey_Management(object):
             # try to verify with GPG
             self.gpg_verify_key(key)
 
-    @pytest.mark.run(after='test_revoke_key')
+    @pytest.mark.order(after='test_revoke_key')
     def test_revoke_key_with_revoker(self):
         pytest.skip("not implemented yet")
 
@@ -643,10 +648,11 @@ class TestPGPKey_Actions(object):
 
             _, vres = c.verify(*vargs)
 
-        assert vres
+            assert vres
 
     def gpg_decrypt(self, message, privkey):
         try:
+            ret = None
             # decrypt with GnuPG
             with gpg.Context(armor=True, offline=True, pinentry_mode=gpg.constants.PINENTRY_MODE_LOOPBACK) as c:
                 c.set_engine_info(gpg.constants.PROTOCOL_OpenPGP, home_dir=gnupghome)
@@ -660,11 +666,11 @@ class TestPGPKey_Actions(object):
                     gpg.core.gpgme.gpgme_op_import(c.wrapped, key_data)
 
                 pt, _, _ = c.decrypt(gpg.Data(string=str(message)), verify=False)
-
-            return pt
+                ret = bytes(pt)
+            return ret
 
         except gpg.errors.GPGMEError:
-            # if we got here, it's because gpg is screwing with us. The tests seem to pass everywhere except in the buildd.
+            # if we got here, it's because gpg is screwing with us. The tests seem to pass everywhere except in the build.
             # Until I can find a better fix, here's another bypass
             return privkey.decrypt(message).message.encode('utf-8')
 
@@ -691,7 +697,7 @@ class TestPGPKey_Actions(object):
         # assert sig.sig.signer_uid == "{:s}".format(sec.userids[0])
         assert next(iter(sig._signature.subpackets['SignersUserID'])).userid == "{:s}".format(targette_sec.userids[0])
         # if not sig.is_expired:
-        #     time.sleep((sig.expires_at - datetime.utcnow()).total_seconds())
+        #     time.sleep((sig.expires_at - datetime.now(timezone.utc)).total_seconds())
         assert sig.is_expired is False
 
         self.sigs['string'] = sig
@@ -700,7 +706,7 @@ class TestPGPKey_Actions(object):
             # verify with GnuPG
             self.gpg_verify(string, sig, targette_pub)
 
-    @pytest.mark.run(after='test_sign_string')
+    @pytest.mark.order(after='test_sign_string')
     def test_verify_string(self, targette_pub, string):
         # verify the signature on the string
         sig = self.sigs['string']
@@ -723,7 +729,7 @@ class TestPGPKey_Actions(object):
             # verify with GnuPG
             self.gpg_verify(message, pubkey=targette_pub)
 
-    @pytest.mark.run(after='test_sign_message')
+    @pytest.mark.order(after='test_sign_message')
     def test_verify_message(self, targette_pub, message):
         # test verifying a signed message
         sv = targette_pub.verify(message)
@@ -732,7 +738,7 @@ class TestPGPKey_Actions(object):
 
     def test_sign_ctmessage(self, targette_sec, targette_pub, ctmessage):
         # test signing a cleartext message
-        expire_at = datetime.utcnow() + timedelta(days=1)
+        expire_at = datetime.now(timezone.utc) + timedelta(days=1)
 
         sig = targette_sec.sign(ctmessage, expires=expire_at)
 
@@ -746,7 +752,7 @@ class TestPGPKey_Actions(object):
             # verify with GnuPG
             self.gpg_verify(ctmessage, pubkey=targette_pub)
 
-    @pytest.mark.run(after='test_sign_ctmessage')
+    @pytest.mark.order(after='test_sign_ctmessage')
     def test_verify_ctmessage(self, targette_pub, ctmessage):
         # test verifying a signed cleartext message
         sv = targette_pub.verify(ctmessage)
@@ -764,7 +770,7 @@ class TestPGPKey_Actions(object):
 
         self.sigs[(sec._key.fingerprint.keyid, 'timestamp')] = sig
 
-    @pytest.mark.run(after='test_sign_timestamp')
+    @pytest.mark.order(after='test_sign_timestamp')
     @pytest.mark.parametrize('pub', pubkeys,
                              ids=[os.path.basename(f) for f in sorted(glob.glob('tests/testdata/keys/*.pub.asc'))])
     def test_verify_timestamp(self, pub):
@@ -789,7 +795,7 @@ class TestPGPKey_Actions(object):
         assert sig.notation == {"cheese status": "standing alone"}
         self.sigs[(sec._key.fingerprint.keyid, 'standalone')] = sig
 
-    @pytest.mark.run(after='test_sign_standalone')
+    @pytest.mark.order(after='test_sign_standalone')
     @pytest.mark.parametrize('pub', pubkeys,
                              ids=[os.path.basename(f) for f in sorted(glob.glob('tests/testdata/keys/*.pub.asc'))])
     def test_verify_standalone(self, pub):
@@ -847,7 +853,7 @@ class TestPGPKey_Actions(object):
         assert sig.exportable
         assert ({sec.fingerprint.keyid} | set(sec.subkeys)) & userid.signers
 
-    @pytest.mark.run(after='test_certify_uid')
+    @pytest.mark.order(after='test_certify_uid')
     @pytest.mark.parametrize('pub', pubkeys,
                              ids=[os.path.basename(f) for f in sorted(glob.glob('tests/testdata/keys/*.pub.asc'))])
     def test_verify_userid(self, pub, abe):
@@ -864,7 +870,7 @@ class TestPGPKey_Actions(object):
         userphoto = abe.userattributes[0]
         userphoto |= sec.certify(userphoto)
 
-    @pytest.mark.run(after='test_certify_photo')
+    @pytest.mark.order(after='test_certify_photo')
     @pytest.mark.parametrize('pub', pubkeys,
                              ids=[os.path.basename(f) for f in sorted(glob.glob('tests/testdata/keys/*.pub.asc'))])
     def test_verify_photo(self, pub, abe):
@@ -917,7 +923,7 @@ class TestPGPKey_Actions(object):
             emsg = pub.encrypt(msg, cipher=cipher)
         self.msgs[(pub.fingerprint, cipher)] = emsg
 
-    @pytest.mark.run(after='test_encrypt_message')
+    @pytest.mark.order(after='test_encrypt_message')
     @pytest.mark.parametrize('sf,cipher',
                              itertools.product(sorted(glob.glob('tests/testdata/keys/*.sec.asc')), sorted(SymmetricKeyAlgorithm)))
     def test_decrypt_message(self, sf, cipher):
@@ -941,7 +947,7 @@ class TestPGPKey_Actions(object):
         if gpg:
             assert self.gpg_decrypt(emsg, sec).decode('utf-8') == dmsg.message
 
-    @pytest.mark.run(after='test_encrypt_message')
+    @pytest.mark.order(after='test_encrypt_message')
     @pytest.mark.parametrize('sf,cipher',
                              itertools.product(sorted(glob.glob('tests/testdata/keys/*.sec.asc')), sorted(SymmetricKeyAlgorithm)))
     def test_sign_encrypted_message(self, sf, cipher):
@@ -973,3 +979,17 @@ class TestPGPKey_Actions(object):
             warnings.simplefilter('ignore')
             dmsg = seckey.decrypt(emsg)
         assert bytes(dmsg.message) == b"This message will have been encrypted"
+
+    def test_ignore_flags(self):
+        # Test that ignoring key flags works properly
+        pubkey, _ = PGPKey.from_file('tests/testdata/keys/targette.pub.rsa.asc')
+        msg = PGPMessage.new('secret message')
+
+        with pytest.raises(PGPError):
+            pubkey.encrypt(msg)
+
+        pubkey._require_usage_flags = False
+        try:
+            pubkey.encrypt(msg)
+        except PGPError as e:
+            pytest.fail("Unexpected exception raised: {}".format(e))
